PredefinedAtom

Enum PredefinedAtom 

#[repr(u32)]
pub enum PredefinedAtom {
Show 205 variants Null = 1, False = 2, True = 3, If = 4, Else = 5, Return = 6, Var = 7, This = 8, Delete = 9, Void = 10, Typeof = 11, New = 12, In = 13, Instanceof = 14, Do = 15, While = 16, For = 17, Break = 18, Continue = 19, Switch = 20, Case = 21, Default = 22, Throw = 23, Try = 24, Catch = 25, Finally = 26, FunctionKw = 27, Debugger = 28, With = 29, Class = 30, Const = 31, Enum = 32, Export = 33, Extends = 34, Import = 35, Super = 36, Implements = 38, Interface = 39, Let = 40, Package = 41, Private = 42, Protected = 43, Public = 44, Static = 45, Yield = 46, Await = 47, Empty = 48, Length = 51, Message = 52, Errors = 54, Stack = 57, Name = 58, ToString = 59, ToLocaleString = 60, ValueOf = 61, Eval = 62, Prototype = 63, Constructor = 64, Configurable = 65, Writable = 66, Enumerable = 67, Value = 68, Getter = 69, Setter = 70, Of = 71, UnderscoreProto = 72, Undefined = 73, NumberLower = 74, BooleanLower = 75, StringLower = 76, ObjectLower = 77, SymbolLower = 78, Integer = 79, Unknown = 80, ArgumentsLower = 81, Callee = 82, Caller = 83, LastIndex = 93, Target = 94, Index = 95, Input = 96, DefineProperties = 97, Apply = 98, Join = 99, Concat = 100, Split = 101, Construct = 102, GetPrototypeOf = 103, SetPrototypeOf = 104, IsExtensible = 105, PreventExtensions = 106, Has = 107, DeleteProperty = 108, DefineProperty = 109, GetOwnPropertyDescriptor = 110, OwnKeys = 111, Add = 112, Done = 113, Next = 114, Values = 115, Source = 116, Flags = 117, Global = 118, Unicode = 119, Raw = 120, NewTarget = 122, ThisActiveFunc = 123, HomeObject = 124, ComputedField = 125, StaticComputedField = 126, ClassFieldsInit = 127, Brand = 128, HashConstructor = 129, As = 130, From = 131, Meta = 133, StarDefault = 134, Star = 135, Module = 136, Then = 137, Resolve = 138, Reject = 139, PromiseLower = 140, ProxyLower = 141, Revoke = 142, Async = 143, Exec = 144, Groups = 145, Status = 147, Reason = 148, GlobalThis = 149, Bigint = 150, ToJSON = 154, MaxByteLength = 155, Object = 158, Array = 159, Error = 160, Number = 161, String = 162, Boolean = 163, Symbol = 164, Arguments = 165, Math = 166, JSON = 167, Date = 168, Function = 169, GeneratorFunction = 170, ForInIterator = 171, Iterator = 195, RegExp = 172, ArrayBuffer = 173, SharedArrayBuffer = 174, Uint8ClampedArray = 175, Int8Array = 176, Uint8Array = 177, Int16Array = 178, Uint16Array = 179, Int32Array = 180, Uint32Array = 181, BigInt64Array = 182, BigUint64Array = 183, Float16Array = 184, Float32Array = 185, Float64Array = 186, DataView = 187, BigInt = 188, Map = 191, Set = 192, WeakMap = 193, WeakSet = 194, MapIterator = 199, SetIterator = 200, ArrayIterator = 201, StringIterator = 202, RegExpStringIterator = 203, Generator = 204, Proxy = 205, Promise = 206, PromiseResolveFunction = 207, PromiseRejectFunction = 208, AsyncFunction = 209, AsyncFunctionResolve = 210, AsyncFunctionReject = 211, AsyncGeneratorFunction = 212, AsyncGenerator = 213, EvalError = 214, RangeError = 215, ReferenceError = 216, SyntaxError = 217, TypeError = 218, URIError = 219, InternalError = 220, SymbolAsyncIterator = 239, SymbolIterator = 228, SymbolMatch = 229, SymbolMatchAll = 230, SymbolReplace = 231, SymbolSearch = 232, SymbolSplit = 233, SymbolToPrimitive = 227, SymbolToStringTag = 234, SymbolIsConcatSpreadable = 235, SymbolHasInstance = 236, SymbolSpecies = 237, SymbolUnscopables = 238,
}
A collection of atoms which are predefined in quickjs.

Using these over Atom::from_str can be more performant as these don’t need to be looked up in a hashmap.

Variants



Null = 1

“null”



False = 2

“false”



True = 3

“true”



If = 4

“if”



Else = 5

“else”



Return = 6

“return”



Var = 7

“var”



This = 8

“this”



Delete = 9

“delete”



Void = 10

“void”



Typeof = 11

“typeof”



New = 12

“new”



In = 13

“in”



Instanceof = 14

“instanceof”



Do = 15

“do”



While = 16

“while”



For = 17

“for”



Break = 18

“break”



Continue = 19

“continue”



Switch = 20

“switch”



Case = 21

“case”



Default = 22

“default”



Throw = 23

“throw”



Try = 24

“try”



Catch = 25

“catch”



Finally = 26

“finally”



FunctionKw = 27

“function”



Debugger = 28

“debugger”



With = 29

“with”



Class = 30

“class”



Const = 31

“const”



Enum = 32

“enum”



Export = 33

“export”



Extends = 34

“extends”



Import = 35

“import”



Super = 36

“super”



Implements = 38

“implements”



Interface = 39

“interface”



Let = 40

“let”



Package = 41

“package”



Private = 42

“private”



Protected = 43

“protected”



Public = 44

“public”



Static = 45

“static”



Yield = 46

“yield”



Await = 47

“await”



Empty = 48

“”



Length = 51

“length”



Message = 52

“message”



Errors = 54

“errors”



Stack = 57

“stack”



Name = 58

“name”



ToString = 59

“toString”



ToLocaleString = 60

“toLocaleString”



ValueOf = 61

“valueOf”



Eval = 62

“eval”



Prototype = 63

“prototype”



Constructor = 64

“constructor”



Configurable = 65

“configurable”



Writable = 66

“writable”



Enumerable = 67

“enumerable”



Value = 68

“value”



Getter = 69

“get”



Setter = 70

“set”



Of = 71

“of”



UnderscoreProto = 72

proto



Undefined = 73

“undefined”



NumberLower = 74

“number”



BooleanLower = 75

“boolean”



StringLower = 76

“string”



ObjectLower = 77

“object”



SymbolLower = 78

“symbol”



Integer = 79

“integer”



Unknown = 80

“unknown”



ArgumentsLower = 81

“arguments”



Callee = 82

“callee”



Caller = 83

“caller”



LastIndex = 93

“lastIndex”



Target = 94

“target”



Index = 95

“index”



Input = 96

“input”



DefineProperties = 97

“defineProperties”



Apply = 98

“apply”



Join = 99

“join”



Concat = 100

“concat”



Split = 101

“split”



Construct = 102

“construct”



GetPrototypeOf = 103

“getPrototypeOf”



SetPrototypeOf = 104

“setPrototypeOf”



IsExtensible = 105

“isExtensible”



PreventExtensions = 106

“preventExtensions”



Has = 107

“has”



DeleteProperty = 108

“deleteProperty”



DefineProperty = 109

“defineProperty”



GetOwnPropertyDescriptor = 110

“getOwnPropertyDescriptor”



OwnKeys = 111

“ownKeys”



Add = 112

“add”



Done = 113

“done”



Next = 114

“next”



Values = 115

“values”



Source = 116

“source”



Flags = 117

“flags”



Global = 118

“global”



Unicode = 119

“unicode”



Raw = 120

“raw”



NewTarget = 122

“new.target”



ThisActiveFunc = 123

“this.active_func”



HomeObject = 124

“<home_object>”



ComputedField = 125

“<computed_field>”



StaticComputedField = 126

“<static_computed_field>”



ClassFieldsInit = 127

“<class_fields_init>”



Brand = 128

“<brand>”



HashConstructor = 129

“#constructor”



As = 130

“as”



From = 131

“from”



Meta = 133

“meta”



StarDefault = 134

default



Star = 135

“*”



Module = 136

“Module”



Then = 137

“then”



Resolve = 138

“resolve”



Reject = 139

“reject”



PromiseLower = 140

“promise”



ProxyLower = 141

“proxy”



Revoke = 142

“revoke”



Async = 143

“async”



Exec = 144

“exec”



Groups = 145

“groups”



Status = 147

“status”



Reason = 148

“reason”



GlobalThis = 149

“globalThis”



Bigint = 150

“bigint”



ToJSON = 154

“toJSON”



MaxByteLength = 155

“toJSON”



Object = 158

“Object”



Array = 159

“Array”



Error = 160

“Error”



Number = 161

“Number”



String = 162

“String”



Boolean = 163

“Boolean”



Symbol = 164

“Symbol”



Arguments = 165

“Arguments”



Math = 166

“Math”



JSON = 167

“JSON”



Date = 168

“Date”



Function = 169

“Function”



GeneratorFunction = 170

“GeneratorFunction”



ForInIterator = 171

“ForInIterator”



Iterator = 195

“Iterator”



RegExp = 172

“RegExp”



ArrayBuffer = 173

“ArrayBuffer”



SharedArrayBuffer = 174

“SharedArrayBuffer”



Uint8ClampedArray = 175

“Uint8ClampedArray”



Int8Array = 176

“Int8Array”



Uint8Array = 177

“Uint8Array”



Int16Array = 178

“Int16Array”



Uint16Array = 179

“Uint16Array”



Int32Array = 180

“Int32Array”



Uint32Array = 181

“Uint32Array”



BigInt64Array = 182

“BigInt64Array”



BigUint64Array = 183

“BigUint64Array”



Float16Array = 184

Available on crate feature half only.

“Float16Array”



Float32Array = 185

“Float32Array”



Float64Array = 186

“Float64Array”



DataView = 187

“DataView”



BigInt = 188

“BigInt”



Map = 191

“Map”



Set = 192

“Set”



WeakMap = 193

“WeakMap”



WeakSet = 194

“WeakSet”



MapIterator = 199

“Map Iterator”



SetIterator = 200

“Set Iterator”



ArrayIterator = 201

“Array Iterator”



StringIterator = 202

“String Iterator”



RegExpStringIterator = 203

“RegExp String Iterator”



Generator = 204

“Generator”



Proxy = 205

“Proxy”



Promise = 206

“Promise”



PromiseResolveFunction = 207

“PromiseResolveFunction”



PromiseRejectFunction = 208

“PromiseRejectFunction”



AsyncFunction = 209

“AsyncFunction”



AsyncFunctionResolve = 210

“AsyncFunctionResolve”



AsyncFunctionReject = 211

“AsyncFunctionReject”



AsyncGeneratorFunction = 212

“AsyncGeneratorFunction”



AsyncGenerator = 213

“AsyncGenerator”



EvalError = 214

“EvalError”



RangeError = 215

“RangeError”



ReferenceError = 216

“ReferenceError”



SyntaxError = 217

“SyntaxError”



TypeError = 218

“TypeError”



URIError = 219

“URIError”



InternalError = 220

“InternalError”



SymbolAsyncIterator = 239

“Symbol.asyncIterator”



SymbolIterator = 228

“Symbol.iterator”



SymbolMatch = 229

“Symbol.match”



SymbolMatchAll = 230

“Symbol.matchAll”



SymbolReplace = 231

“Symbol.replace”



SymbolSearch = 232

“Symbol.search”



SymbolSplit = 233

“Symbol.split”



SymbolToPrimitive = 227

“Symbol.toPrimitive”



SymbolToStringTag = 234

“Symbol.toStringTag”



SymbolIsConcatSpreadable = 235

“Symbol.isConcatSpreadable”



SymbolHasInstance = 236

“Symbol.hasInstance”



SymbolSpecies = 237

“Symbol.species”



SymbolUnscopables = 238

“Symbol.unscopables”

Implementations

Source

impl PredefinedAtom

pub const fn is_symbol(self) -> bool

pub const fn to_str(self) -> &'static str