JavaScript classes defined from Rust.
Structs
- Borrow
- A borrow guard for a borrowed class.
- Borrow
Mut - A borrow guard for a mutably borrowed class.
- Class
- A object which is instance of a Rust class.
- JsCell
- A cell type for Rust classes passed to JavaScript.
- Owned
Borrow - An owned borrow of a class object which keeps the borrow alive for the duration of the objects lifetime.
- Owned
Borrow Mut - An owned mutable borrow of a class object which keeps the borrow alive for the duration of the objects lifetime.
- Property
Descriptor - A JavaScript property descriptor returned from
JsClass::exotic_get_own_property. - Property
Name - A property name entry returned from
JsClass::exotic_get_own_property_names. - Tracer
- An object used for tracing references
Enums
- Class
Kind - The kind of a JavaScript class.
- Readable
- A marker type used for marking the mutability of a class.
When a class has
Readableas it Mutable type you can only borrow it immutable. - Writable
- A marker type used for marking the mutability of a class.
When a class has
Writableas it Mutable type you can borrow it both mutability and immutable.
Traits
- JsClass
- The trait which allows Rust types to be used from JavaScript.
- Mutability
- A trait to allow classes to choose there borrowing implementation.
- Trace
- A trait for classes for tracing references to QuickJS objects.