pub trait HasByteCode<'bc> {
// Required method
fn get_bytecode(&self) -> &'bc [u8] ⓘ;
}Available on crate feature
loader only.Expand description
The module data which contains bytecode
This trait needed because the modules potentially can contain any kind of data like a typing (for TypeScript) or metadata.
Required Methods
fn get_bytecode(&self) -> &'bc [u8] ⓘ
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".