pub trait IntoJs<'js> {
// Required method
fn into_js(self, ctx: &Ctx<'js>) -> Result<Value<'js>>;
}Expand description
For converting Rust values to JavaScript values
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'js> IntoJs<'js> for SystemTime
Available on crate feature std only.
impl<'js> IntoJs<'js> for SystemTime
std only.Sourceimpl<'js, K, V, S> IntoJs<'js> for &HashMap<K, V, S>
Available on crate feature std only.Convert from Rust hash map to JS object
impl<'js, K, V, S> IntoJs<'js> for &HashMap<K, V, S>
std only.Convert from Rust hash map to JS object
Sourceimpl<'js, K, V, S> IntoJs<'js> for &HashMap<K, V, S>
Convert from hashbrown hash map to JS object
impl<'js, K, V, S> IntoJs<'js> for &HashMap<K, V, S>
Convert from hashbrown hash map to JS object
Sourceimpl<'js, K, V, S> IntoJs<'js> for &IndexMap<K, V, S>
Available on crate feature indexmap only.Convert from Rust index map to JS object
impl<'js, K, V, S> IntoJs<'js> for &IndexMap<K, V, S>
indexmap only.Convert from Rust index map to JS object
Sourceimpl<'js, K, V, S> IntoJs<'js> for HashMap<K, V, S>
Available on crate feature std only.Convert from Rust hash map to JS object
impl<'js, K, V, S> IntoJs<'js> for HashMap<K, V, S>
std only.Convert from Rust hash map to JS object
Sourceimpl<'js, K, V, S> IntoJs<'js> for HashMap<K, V, S>
Convert from hashbrown hash map to JS object
impl<'js, K, V, S> IntoJs<'js> for HashMap<K, V, S>
Convert from hashbrown hash map to JS object
Sourceimpl<'js, K, V, S> IntoJs<'js> for IndexMap<K, V, S>
Available on crate feature indexmap only.Convert from Rust index map to JS object
impl<'js, K, V, S> IntoJs<'js> for IndexMap<K, V, S>
indexmap only.Convert from Rust index map to JS object
Sourceimpl<'js, L, R> IntoJs<'js> for &Either<L, R>
Available on crate feature either only.Convert the either into JS
impl<'js, L, R> IntoJs<'js> for &Either<L, R>
either only.Convert the either into JS
Sourceimpl<'js, L, R> IntoJs<'js> for Either<L, R>
Available on crate feature either only.Convert the either into JS
impl<'js, L, R> IntoJs<'js> for Either<L, R>
either only.Convert the either into JS
Sourceimpl<'js, T> IntoJs<'js> for &LinkedList<T>
Convert from Rust linked list to JS array
impl<'js, T> IntoJs<'js> for &LinkedList<T>
Convert from Rust linked list to JS array
Sourceimpl<'js, T> IntoJs<'js> for BTreeSet<T>where
T: IntoJs<'js>,
Convert from Rust btree set to JS array
impl<'js, T> IntoJs<'js> for BTreeSet<T>where
T: IntoJs<'js>,
Convert from Rust btree set to JS array
Sourceimpl<'js, T> IntoJs<'js> for LinkedList<T>where
T: IntoJs<'js>,
Convert from Rust linked list to JS array
impl<'js, T> IntoJs<'js> for LinkedList<T>where
T: IntoJs<'js>,
Convert from Rust linked list to JS array
Sourceimpl<'js, T> IntoJs<'js> for VecDeque<T>where
T: IntoJs<'js>,
Convert from Rust vector deque to JS array
impl<'js, T> IntoJs<'js> for VecDeque<T>where
T: IntoJs<'js>,
Convert from Rust vector deque to JS array
Sourceimpl<'js, T> IntoJs<'js> for Mutex<T>where
T: IntoJs<'js>,
Available on crate feature std only.
impl<'js, T> IntoJs<'js> for Mutex<T>where
T: IntoJs<'js>,
std only.Sourceimpl<'js, T> IntoJs<'js> for RwLock<T>where
T: IntoJs<'js>,
Available on crate feature std only.
impl<'js, T> IntoJs<'js> for RwLock<T>where
T: IntoJs<'js>,
std only.Sourceimpl<'js, T, S> IntoJs<'js> for &HashSet<T, S>
Available on crate feature std only.Convert from Rust hash set to JS array
impl<'js, T, S> IntoJs<'js> for &HashSet<T, S>
std only.Convert from Rust hash set to JS array
Sourceimpl<'js, T, S> IntoJs<'js> for &IndexSet<T, S>
Available on crate feature indexmap only.Convert from Rust index set to JS array
impl<'js, T, S> IntoJs<'js> for &IndexSet<T, S>
indexmap only.Convert from Rust index set to JS array
Sourceimpl<'js, T, S> IntoJs<'js> for HashSet<T, S>where
T: IntoJs<'js>,
Available on crate feature std only.Convert from Rust hash set to JS array
impl<'js, T, S> IntoJs<'js> for HashSet<T, S>where
T: IntoJs<'js>,
std only.Convert from Rust hash set to JS array
Sourceimpl<'js, T, S> IntoJs<'js> for HashSet<T, S>where
T: IntoJs<'js>,
Convert from hashbrown hash set to JS array
impl<'js, T, S> IntoJs<'js> for HashSet<T, S>where
T: IntoJs<'js>,
Convert from hashbrown hash set to JS array
Sourceimpl<'js, T, S> IntoJs<'js> for IndexSet<T, S>where
T: IntoJs<'js>,
Available on crate feature indexmap only.Convert from Rust index set to JS array
impl<'js, T, S> IntoJs<'js> for IndexSet<T, S>where
T: IntoJs<'js>,
indexmap only.Convert from Rust index set to JS array
Implementors
impl<'js> IntoJs<'js> for &CString<'js>
impl<'js> IntoJs<'js> for &Value<'js>
impl<'js> IntoJs<'js> for MaybePromise<'js>
impl<'js> IntoJs<'js> for ProxyHandler<'js>
impl<'js> IntoJs<'js> for Array<'js>
impl<'js> IntoJs<'js> for ArrayBuffer<'js>
impl<'js> IntoJs<'js> for BigInt<'js>
impl<'js> IntoJs<'js> for CString<'js>
impl<'js> IntoJs<'js> for Constructor<'js>
impl<'js> IntoJs<'js> for Exception<'js>
impl<'js> IntoJs<'js> for Function<'js>
impl<'js> IntoJs<'js> for Null
impl<'js> IntoJs<'js> for Object<'js>
impl<'js> IntoJs<'js> for Promise<'js>
impl<'js> IntoJs<'js> for Proxy<'js>
impl<'js> IntoJs<'js> for rquickjs_core::String<'js>
impl<'js> IntoJs<'js> for Symbol<'js>
impl<'js> IntoJs<'js> for Undefined
impl<'js> IntoJs<'js> for Value<'js>
impl<'js, A> IntoJs<'js> for List<(A,)>where
A: IntoJs<'js>,
impl<'js, A, B> IntoJs<'js> for List<(A, B)>
impl<'js, A, B, C> IntoJs<'js> for List<(A, B, C)>
impl<'js, A, B, C, D> IntoJs<'js> for List<(A, B, C, D)>
impl<'js, A, B, C, D, E> IntoJs<'js> for List<(A, B, C, D, E)>
impl<'js, A, B, C, D, E, F> IntoJs<'js> for List<(A, B, C, D, E, F)>
impl<'js, A, B, C, D, E, F, G> IntoJs<'js> for List<(A, B, C, D, E, F, G)>
impl<'js, A, B, C, D, E, F, G, H> IntoJs<'js> for List<(A, B, C, D, E, F, G, H)>
impl<'js, A, B, C, D, E, F, G, H, I> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I)>
impl<'js, A, B, C, D, E, F, G, H, I, J> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K, L> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K, L)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K, L, M> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K, L, M)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K, L, M, N> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K, L, M, N)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)>
impl<'js, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> IntoJs<'js> for List<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)>
impl<'js, C: JsClass<'js>> IntoJs<'js> for Class<'js, C>
impl<'js, F> IntoJs<'js> for Iterable<F>
impl<'js, T> IntoJs<'js> for Persistent<T>
impl<'js, T> IntoJs<'js> for TypedArray<'js, T>
impl<'js, T, P> IntoJs<'js> for Func<T, P>where
T: IntoJsFunc<'js, P> + 'js,
impl<'js, T, R> IntoJs<'js> for Promised<T>
futures only.